##
##  rbldnsd.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2008 OpenPKG Foundation e.V. <http://openpkg.net/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         rbldnsd
Summary:      Realtime Blackhole List (RBL) DNS Daemon
URL:          http://www.corpit.ru/mjt/rbldnsd.html
Vendor:       Michael Tokarev
Packager:     OpenPKG Foundation e.V.
Distribution: OpenPKG Community
Class:        PLUS
Group:        DNS
License:      GPL
Version:      0.996b
Release:      20080329

#   package options
%option       with_fsl    yes

#   list of sources
Source0:      http://www.corpit.ru/mjt/rbldnsd/rbldnsd_%{version}.tar.gz
Source1:      rc.rbldnsd
Source3:      fsl.rbldnsd
Source4:      rbldnsd.zones
Source5:      zone.rbl
Patch0:       rbldnsd.patch

#   build information
Prefix:       %{l_prefix}
BuildRoot:    %{l_buildroot}
BuildPreReq:  OpenPKG, openpkg >= 20060823, gcc
PreReq:       OpenPKG, openpkg >= 20060823
%if "%{with_fsl}" == "yes"
BuildPreReq:  fsl
PreReq:       fsl
%endif
AutoReq:      no
AutoReqProv:  no

%description
    RBLDNSD is a small authoritate-only DNS nameserver designed to serve
    DNS-based blocklists (DNSBLs). It may handle IP-based and name-based
    blocklists. It is extremely fast and outperforms BIND greatly. It
    has very small memory footprint.

%track
    prog rbldnsd = {
        version   = %{version}
        url       = http://www.corpit.ru/mjt/rbldnsd/
        regex     = rbldnsd_(__VER__)\.tar\.gz
    }

%prep
    %setup -q
    %patch -p0

%build
    #   configure program
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags} %{l_fsl_ldflags}" \
    LIBS="%{l_fsl_libs}" \
    ./configure

    #   build program
    %{l_make} %{l_mflags}

%install
    #   create installation hierarchy
    rm -rf $RPM_BUILD_ROOT
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/fsl \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rbldnsd \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/man/man8 \
        $RPM_BUILD_ROOT%{l_prefix}/var/rbldnsd

    #   install program and manual page
    %{l_shtool} install -c -s -m 755 \
        rbldnsd $RPM_BUILD_ROOT%{l_prefix}/sbin/
    %{l_shtool} install -c -m 644 \
        rbldnsd.8 $RPM_BUILD_ROOT%{l_prefix}/man/man8/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.rbldnsd} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   install OSSP fsl configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE fsl.rbldnsd}  $RPM_BUILD_ROOT%{l_prefix}/etc/fsl/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE rbldnsd.zones} %{SOURCE zone.rbl} \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rbldnsd/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/fsl/*' \
        '%config %{l_prefix}/etc/rbldnsd/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/rbldnsd'

%files -f files

%clean
    rm -rf $RPM_BUILD_ROOT

